@@ -285,9 +285,8 @@ class ClientProxy(object):
 
         return False
 
-    def _apply_naming_convention(name):
-	    cased_segments = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', name)
-	    return re.sub('([a-z0-9])([A-Z])', r'\1_\2', cased_segments).lower()
+    def _apply_naming_convention(self, value):
+	    return re.sub(r'(?!^)_([a-zA-Z])', lambda m: m.group(1).upper(), value)
 
 class API(ClientProxy):
     """
